# -*- coding: utf-8 -*-
from setuptools import setup

setup(
    name='antsibull-docs',
    version='2.2.0',
    description='Tools for building Ansible documentation',
    author_email='Toshio Kuratomi <a.badger@gmail.com>, Felix Fontein <felix@fontein.de>',
    maintainer_email='Felix Fontein <felix@fontein.de>, Maxwell G <maxwell@gtmx.me>',
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Framework :: Ansible',
        'Intended Audience :: Developers',
        'Programming Language :: Python :: 3.9',
        'Programming Language :: Python :: 3.10',
        'Programming Language :: Python :: 3.11',
        'Typing :: Typed',
    ],
    install_requires=[
        'aiohttp>=3.0.0',
        'ansible-pygments',
        'antsibull-core<3.0.0,>=2.0.0',
        'antsibull-docs-parser<2.0.0,>=1.0.0',
        'asyncio-pool',
        'docutils',
        'jinja2>=3.0',
        'packaging',
        'pydantic<2.0.0,>=1.0.0',
        'pyyaml',
        'rstcheck<7.0.0,>=3.0.0',
        'semantic-version',
        'sphinx',
        'twiggy',
    ],
    extras_require={
        'codeqa': [
            'antsibull-changelog',
            'flake8>=3.8.0',
            'pylint>=2.17.2',
            'reuse',
        ],
        'coverage': [
            'coverage[toml]',
        ],
        'dev': [
            'antsibull-docs[codeqa]',
            'antsibull-docs[formatters]',
            'antsibull-docs[test]',
            'antsibull-docs[typing]',
            'nox',
        ],
        'formatters': [
            'black',
            'isort',
        ],
        'test': [
            'ansible-core>=2.14.0',
            'asynctest',
            'cryptography',
            'pytest',
            'pytest-asyncio>=0.12',
            'pytest-cov',
            'pytest-error-for-skips',
        ],
        'typing': [
            'mypy',
            'pyre-check>=0.9.17',
            'types-aiofiles',
            'types-docutils',
            'types-pyyaml',
        ],
    },
    entry_points={
        'console_scripts': [
            'antsibull-docs = antsibull_docs.cli.antsibull_docs:main',
        ],
    },
    packages=[
        'antsibull_docs',
        'antsibull_docs.cli',
        'antsibull_docs.cli.doc_commands',
        'antsibull_docs.data',
        'antsibull_docs.data.docsite',
        'antsibull_docs.docs_parsing',
        'antsibull_docs.jinja2',
        'antsibull_docs.markup',
        'antsibull_docs.schemas',
        'antsibull_docs.schemas.docs',
        'antsibull_docs.utils',
        'antsibull_docs.write_docs',
        'sphinx_antsibull_ext',
    ],
    package_dir={'': 'src'},
)
